/* 
 * PPRacer 
 * Copyright (C) 2004 Volker Stroebel <volker@planetpenguin.de>
 *
 * Copyright (C) 1999-2001 Jasmin F. Patry
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "ssbutton.h"

#include "textures.h"

#include "render_util.h"

#include "ui_mgr.h"


namespace pp {
	
SSButton::SSButton(pp::Vec2d pos, pp::Vec2d size,int num_states )
{
   	this->position = pos;
    this->size=size;
	
    this->num_states = num_states;
	this->regions = new texture_region_t[num_states];

    for (int i=0; i<num_states; i++) {
		this->regions[i].binding = NULL;
    }

    this->current_state = 0;

    this->enabled = true;
    this->visible = false;
    this->active = false;
}

SSButton::~SSButton()
{
    setVisible( false );
    setActive( false );
    delete regions;	
}

void
SSButton::setState( int state )
{
	current_state = state;

    if ( visible ) {
		UIMgr.setDirty();
    }
}


void
SSButton::setStateImage( int state,
			       char *binding,
			       pp::Vec2d ll, pp::Vec2d ur, 
			       pp::Color color )
{
	regions[state].binding = binding;
    regions[state].color = color;
    regions[state].ll = ll;
    regions[state].ur = ur;
}

void
SSButton::performClickAction()
{
	current_state = ( current_state + 1 ) %num_states;
	signalClicked.Emit();
}

void
SSButton::draw()
{
	GLuint texobj;
	
	glEnable( GL_TEXTURE_2D );
	
	if ( !get_texture_binding( regions[current_state].binding, &texobj ) ) {
		print_warning( IMPORTANT_WARNING,
			   "Couldnt get texture object for binding %s",
			   regions[current_state].binding );
	    texobj = 0;
	}

	glBindTexture( GL_TEXTURE_2D, texobj );

	glColor4dv( (double*) &regions[current_state].color );

	glBegin( GL_QUADS );
	{
	    glTexCoord2f( regions[current_state].ll.x, regions[current_state].ll.y );
	    glVertex3f( position.x, position.y, 0 );

	    glTexCoord2f( regions[current_state].ur.x, regions[current_state].ll.y );
	    glVertex3f( position.x + size.x, position.y, 0 );

	    glTexCoord2f( regions[current_state].ur.x, regions[current_state].ur.y );
	    glVertex3f( position.x + size.x, position.y + size.y, 0 );

	    glTexCoord2f( regions[current_state].ll.x, regions[current_state].ur.y );
	    glVertex3f( position.x, position.y + size.y, 0 );
	}
	glEnd();

}
	
} //namespace pp
